@@ -10,7 +10,7 @@ from pygments import highlight, lexers, formatters
 
 def get_args():
     parser = argparse.ArgumentParser(description='Process a JSONPath expression over a JSON read from <stdin>.')
-    parser.add_argument('jsonpath', help='valid jsonpath expression')
+    parser.add_argument('jsonpath', help='valid jsonpath expression', nargs='?', default='$')
     parser.add_argument('--color', help='enable/disable colored highlights', action=argparse.BooleanOptionalAction, default=True)
     parser.add_argument('-f', '--format', '-i', '--indent', help='enable/disable formatting output', action=argparse.BooleanOptionalAction, default=False)
 
